darkhistory.electrons.positronium.para_photon_spec — DarkHistory documentation

# darkhistory.electrons.positronium.para_photon_spec

`darkhistory.electrons.positronium.` `para_photon_spec`(eng)

  Returns the photon spectrum from parapositronium annihilation.

  This is normalized to a single annihilation, producing 2 photons.

  Parameters: | eng : ndarray The energy abscissa.
  Returns: | Spectrum The resulting photon `Spectrum` object.

  See also

  `rebin_N_arr()`

#### Previous topic

darkhistory.electrons.positronium.ortho_photon_spec

#### Next topic

darkhistory.electrons.positronium.weighted_photon_spec

### This Page

Show Source